.. :changelog:

History
-------

0.1.0 (2017-04-15)
++++++++++++++++++

* First release on PyPI.

0.1.1 (2017-05-12)
++++++++++++++++++

* Added tests for models, forms, views
* Urls that include topic titles with spaces in them don't work // fixed
* Competability fixes for Django 1.9 and 1.8 and Python 2.7

0.1.2 (2017-05-19)
++++++++++++++++++

* Updated documentation
* client side fixes for added compatibility with mobile screen sizes

0.1.3 (2017-05-23)
++++++++++++++++++

* font-awsome fonts are not loading // fixed

0.1.4 (2017-05-24)
++++++++++++++++++

* Added description field for Topic
* added description for topics in /topics page
* updated migrations

0.1.5 (2017-05-26)
++++++++++++++++++

* moved base.html to root template dir

0.1.6 (2017-06-03)
++++++++++++++++++

* Admins can lock/unlock & delete threads, delete posts
* Added description to Topic creation form

0.1.7 (2017-06-09)
++++++++++++++++++

* Admins can thread title, url, and post content
